==> jc-1.4.0.tar.gz: java/rmi/RMISecurityException.h <==
// public class java.rmi.RMISecurityException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 767fc1626c63609e java_lang_SecurityException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3f032dc7d5ac2a84 java_rmi_RMISecurityException

// header file dependencies
// @dep_header java_lang_SecurityException

#include "java/lang/SecurityException.h"

#ifndef _JC_java_rmi_RMISecurityException_H_
#define _JC_java_rmi_RMISecurityException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_RMISecurityException$sub_refs	_jc_java_rmi_RMISecurityException$sub_refs;
typedef struct _jc_java_rmi_RMISecurityException$sub_nonrefs	_jc_java_rmi_RMISecurityException$sub_nonrefs;
typedef struct _jc_java_rmi_RMISecurityException$refs	_jc_java_rmi_RMISecurityException$refs;
typedef struct _jc_java_rmi_RMISecurityException$nonrefs	_jc_java_rmi_RMISecurityException$nonrefs;
typedef struct _jc_java_rmi_RMISecurityException$object	_jc_java_rmi_RMISecurityException$object;

typedef struct _jc_java_rmi_RMISecurityException$fields_struct	_jc_java_rmi_RMISecurityException$fields_struct;
typedef const struct _jc_java_rmi_RMISecurityException$vmethods	_jc_java_rmi_RMISecurityException$vmethods;
typedef const struct _jc_java_rmi_RMISecurityException$vtable	_jc_java_rmi_RMISecurityException$vtable;
typedef const struct _jc_java_rmi_RMISecurityException$vtype	_jc_java_rmi_RMISecurityException$vtype;

// Class fields structure
struct _jc_java_rmi_RMISecurityException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_RMISecurityException$fields_struct _jc_java_rmi_RMISecurityException$class_fields;

// Constructors
extern void _jc_java_rmi_RMISecurityException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_RMISecurityException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_RMISecurityException$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_rmi_RMISecurityException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_rmi_RMISecurityException$vmethods {
};

// Vtable
struct _jc_java_rmi_RMISecurityException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_SecurityException$vmethods	java_lang_SecurityException;
	_jc_java_rmi_RMISecurityException$vmethods	java_rmi_RMISecurityException;
};

// Vtype
struct _jc_java_rmi_RMISecurityException$vtype {
	_jc_type			type;
	_jc_java_rmi_RMISecurityException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_RMISecurityException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_RMISecurityException$refs {
    _jc_java_rmi_RMISecurityException$sub_refs	java_rmi_RMISecurityException;
    _jc_java_lang_SecurityException$sub_refs	java_lang_SecurityException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_RMISecurityException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_RMISecurityException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_SecurityException$sub_nonrefs	java_lang_SecurityException;
    _jc_java_rmi_RMISecurityException$sub_nonrefs	java_rmi_RMISecurityException;
};

// Object instance structure
struct _jc_java_rmi_RMISecurityException$object {
	_jc_java_rmi_RMISecurityException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_RMISecurityException$vtype	*vtype;
	_jc_java_rmi_RMISecurityException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_RMISecurityException$vtype _jc_java_rmi_RMISecurityException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_RMISecurityException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_RMISecurityException$class_object;

#endif	/* _JC_java_rmi_RMISecurityException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/RMISecurityException.h <==
// public class java.rmi.RMISecurityException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 767fc1626c63609e java_lang_SecurityException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3f032dc7d5ac2a84 java_rmi_RMISecurityException

// header file dependencies
// @dep_header java_lang_SecurityException

#include "java/lang/SecurityException.h"

#ifndef _JC_java_rmi_RMISecurityException_H_
#define _JC_java_rmi_RMISecurityException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_RMISecurityException$sub_refs	_jc_java_rmi_RMISecurityException$sub_refs;
typedef struct _jc_java_rmi_RMISecurityException$sub_nonrefs	_jc_java_rmi_RMISecurityException$sub_nonrefs;
typedef struct _jc_java_rmi_RMISecurityException$refs	_jc_java_rmi_RMISecurityException$refs;
typedef struct _jc_java_rmi_RMISecurityException$nonrefs	_jc_java_rmi_RMISecurityException$nonrefs;
typedef struct _jc_java_rmi_RMISecurityException$object	_jc_java_rmi_RMISecurityException$object;

typedef struct _jc_java_rmi_RMISecurityException$fields_struct	_jc_java_rmi_RMISecurityException$fields_struct;
typedef const struct _jc_java_rmi_RMISecurityException$vmethods	_jc_java_rmi_RMISecurityException$vmethods;
typedef const struct _jc_java_rmi_RMISecurityException$vtable	_jc_java_rmi_RMISecurityException$vtable;
typedef const struct _jc_java_rmi_RMISecurityException$vtype	_jc_java_rmi_RMISecurityException$vtype;

// Class fields structure
struct _jc_java_rmi_RMISecurityException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_RMISecurityException$fields_struct _jc_java_rmi_RMISecurityException$class_fields;

// Constructors
extern void _jc_java_rmi_RMISecurityException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_RMISecurityException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_RMISecurityException$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_rmi_RMISecurityException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_RMISecurityException$vmethods {
};

// Vtable
struct _jc_java_rmi_RMISecurityException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_SecurityException$vmethods	java_lang_SecurityException;
	_jc_java_rmi_RMISecurityException$vmethods	java_rmi_RMISecurityException;
};

// Vtype
struct _jc_java_rmi_RMISecurityException$vtype {
	_jc_type			type;
	_jc_java_rmi_RMISecurityException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_RMISecurityException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_RMISecurityException$refs {
    _jc_java_rmi_RMISecurityException$sub_refs	java_rmi_RMISecurityException;
    _jc_java_lang_SecurityException$sub_refs	java_lang_SecurityException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_RMISecurityException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_RMISecurityException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_SecurityException$sub_nonrefs	java_lang_SecurityException;
    _jc_java_rmi_RMISecurityException$sub_nonrefs	java_rmi_RMISecurityException;
};

// Object instance structure
struct _jc_java_rmi_RMISecurityException$object {
	_jc_java_rmi_RMISecurityException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_RMISecurityException$vtype	*vtype;
	_jc_java_rmi_RMISecurityException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_RMISecurityException$vtype _jc_java_rmi_RMISecurityException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_RMISecurityException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_RMISecurityException$class_object;

#endif	/* _JC_java_rmi_RMISecurityException_H_ */
